@@ -11,7 +11,8 @@ extensions = ['otcdocstheme']
 
 # openstackdocstheme options
 otcdocs_repo_name = 'opentelekomcloud/otcdocstheme'
-otcdocs_bug_project = 'opentelekomcloud/otcdocstheme'
+otcdocs_pdf_link = True
+otcdocs_pdf_filename = 'doc-otcdocs.pdf'
 
 # The suffix of source filenames.
 source_suffix = '.rst'
@@ -45,7 +46,9 @@ html_theme = 'otcdocs'
 # variable, sidebar_dropdown, should be set to `api_ref`.
 # Otherwise, the list of links for the User and Ops docs
 # appear in the sidebar dropdown menu.
-html_theme_options = {'show_other_versions': True}
+html_theme_options = {
+    'show_other_versions': True,
+}
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
